@@ -28,5 +28,5 @@ google = OAuth2Provider(
     userinfo_endpoint="https://openidconnect.googleapis.com/v1/userinfo",
     revocation_endpoint="https://oauth2.googleapis.com/revoke",
     userinfo_parser=parse_user,
-    scope="openid email profile",
+    scopes=["openid", "email", "profile"],
 )
