@@ -21,8 +21,13 @@ class YAOAuth2:
     # Configuration
     #
 
-    def add_provider(self, name: str, client_id: str, client_secret: str):
-        self.config.add_provider(name, client_id, client_secret)
+    def add_provider(self, name: str, client_id: str, client_secret: str, additional_scopes: list[str] | None = None):
+        """Add a new OAuth2 provider."""
+
+        if additional_scopes is None:
+            additional_scopes = []
+
+        self.config.add_provider(name, client_id, client_secret, additional_scopes)
 
     #
     # FastAPI router
@@ -74,7 +79,7 @@ class YAOAuth2:
     async def refresh_token(self, provider_name: str, refresh_token: str):
         """Refresh an access token."""
         try:
-            provider = oauth2providers[provider_name]
+            _ = oauth2providers[provider_name]
         except KeyError:
             return
         provider_config = get_provider_config(provider_name)
